@@ -157,7 +157,10 @@ class SQLConnector():
         Lee los parámetros encriptados para conectarse a la BD.
         Convierte el texto de parámetros a un diccionario'''
         
-        txt_enc = Path(dirs.get_dc_cfg()  + '\\' + 'cfg.db').read_text()
+        txt_enc = (
+            Path(dirs.get_dc_cfg()  + '\\' + 'cfg.db')
+            .read_text()
+        )
         
         f = Fernet('chcoJbbFgDtz1dZIDg9g2JIfcCcTlG33q8I3SIJEixE=')
         
